"""CLI entry point for tgulls-hello."""

from tgulls_hello import __version__


def main() -> None:
    """Print a greeting and exit."""
    print("Hello, PyPI!")


if __name__ == "__main__":
    main()
